@@ -1,4 +1,6 @@
+import time
 from abc import abstractmethod
+from logging import info
 
 
 class Abstract:
@@ -47,8 +49,25 @@ class Abstract:
         return url
 
     def after_file_save(self, _path: str, idx: int):
+        self._wait_after_file()
         return _path, None
 
     @abstractmethod
     def chapter_for_json(self) -> str:
         pass
+
+    def _wait_after_file(self):
+        if hasattr(self, '_params'):
+            wait_time = self._params.get('wait_after_page', 0)
+
+            if wait_time > 0:
+                info(f'Wait {wait_time} second(s) / file')
+                time.sleep(wait_time)
+
+    def _wait_after_chapter(self):
+        if hasattr(self, '_params'):
+            wait_time = self._params.get('wait_after_chapter', 0)
+
+            if wait_time > 0:
+                info(f'Wait {wait_time} second(s) / chapter')
+                time.sleep(wait_time)
