@@ -169,8 +169,135 @@ providers_list = {
         r'inmanga\.com/ver/manga/.',
     ],
     'isekaiscan_com': [
-        r'isekaiscan\.com/manga/.',
+        r'mangadods\.com/manga/.',
+        r'mangaus\.xyz/manga/.',
+        r'nitroscans\.com/manga/.',
+        r's2manga\.com/manga/.',
+        r'manytoon\.com/manga/.',
+        r'socialweebs\.in/manga/.',
+        r'toongod\.com/manga/.',
+        r'mangakik\.com/manga/.',
+        r'kissmanga\.in/manga/.',
+        r'soloscanlation\.site/manga/.',
+        r'manhuaes\.com/manga/.',
+        r'manhuasy\.com/manga/.',
+        r'grazescans\.com/manga/.',
+        r'sixiangscans\.com/manga/.',
+        r'toonpoint\.com/manga/.',
+        r'mangasco\.com/manga/.',
+        r'lilymanga\.com/manga/.',
+        r'mangacultivator\.com/manga/.',
+        r'365manga\.com/manga/.',
+        r'freewebtooncoins\.com/manga/.',
+        r'mangatoo\.com/manga/.',
+        r'webtoon\.xyz/manga/.',
+        r'mangaweebs\.in/manga/.',
+        r'manhuabox.net/manga/.',
+        r'mangaread\.org/manga/.',
+        r'manga1st\.com/manga/.',
+        r'aloalivn\.com/manga/.',
+        r'skscans\.com/manga/.',
+        r'imperfectcomic\.com/manga/.',
+        r'astrallibrary\.net/manga/.',
+        r'manhwa\.live/manga/.',
+        r'mangasy\.com/manga/.',
+        r'woopread\.com/manga/.',
+        r'allporncomic\.com/manga/.',
+        r'mangarockteam\.com/manga/.',
+        r'kisekimanga\.com/manga/.',
+        r'mixedmanga\.com/manga/.',
+        r'mangaturf\.com/manga/.',
+        r'manganelo\.link/manga/.',
+        r'webtoonily\.com/manga/.',
+        r'mangabin\.com/manga/.',
+        r'vanguardbun\.com/manga/.',
+        r'webnovel\.live/manga/.',
+        r'mangarocky\.com/manga/.',
+        r'catonhead\.com/manga/.',
+        r'voidscans\.com/manga/.',
+        r'mm-scans\.com/manga/.',
+        r'shoujohearts\.com/manga/.',
+        r'wuxiaworld\.site/manga/.',
+        r'ntsvoidscans\.com/manga/.',
+        r'toonily\.com/manga/.',
+        r'manhuasworld\.com/manga/.',
+        r'mangatx\.com/manga/.',
+        r'manhwatop\.com/manga/.',
+        r'manga18fx\.com/manga/.',
+        r'randomtranslations\.com/manga/.',
+        r'pmscans\.com/manga/.',
+        r'mangazukinew\.online/manga/.',
+        r'mangahentai\.me/manga/.',
+        r'mangachill\.com/manga/.',
+        r'manga347\.com/manga/.',
+        r'mangaeffect\.com/manga/.',
+        r'manga1st\.online/manga/.',
+        r'shieldmanga\.club/manga/.',
+        r'zinmanga\.com/manga/.',
+        r'en.ruyamanga\.com/manga/.',
+        r'manhuaga\.com/manga/.',
+        r'miraclescans\.com/manga/.',
+        r'manhuas\.net/manga/.',
+        r'twilightscans\.com/manga/.',
+        r'manga3s\.com/manga/.',
+        r'skymanga\.co/manga/.',
         r'leviatanscans\.com/manga/.',
+        r'isekaiscanmanga\.com/manga/.',
+        r'itsyourightmanhua\.com/manga/.',
+        r'1stkissmanhua\.com/manga/.',
+        r'isekaiscan\.com/manga/.',
+        r'reader.decadencescans\.com/manga/.',
+        r'manhwa\.club/manga/.',
+        r'manytoon\.me/manga/.',
+        r'nekoscan\.com/manga/.',
+        r'disasterscans\.com/manga/.',
+        r'topmanhua\.com/manga/.',
+        r'mangakiss\.org/manga/.',
+        r'animangaes\.com/manga/.',
+        r'einherjarscans\.space/manga/.',
+        r'porncomixonline\.net/manga/.',
+        r'mortalsgroove\.com/manga/.',
+        r'milftoon\.xxx/manga/.',
+        r'manhuafast\.com/manga/.',
+        r'raiderscans\.com/manga/.',
+        r'mangaclash\.com/manga/.',
+        r'immortalupdates\.com/manga/.',
+        r'aoc\.moe/manga/.',
+        r'tritinia\.com/manga/.',
+        r'bestmanhua\.com/manga/.',
+        r'mangagreat\.com/manga/.',
+        r'new.renascans\.com/manga/.',
+        r'manhuaplus\.com/manga/.',
+        r'toonily\.net/manga/.',
+        r'webtoon\.uk/manga/.',
+        r'nazarickscans\.com/manga/.',
+        r'herozscans\.com/manga/.',
+        r'mangalord\.com/manga/.',
+        r'hscans\.com/manga/.',
+        r'boyslove\.me/manga/.',
+        r'heromanhua\.com/manga/.',
+        r'mangabob\.com/manga/.',
+        r'wescans\.xyz/manga/.',
+        r'arangscans\.com/manga/.',
+        r'mangaroma\.com/manga/.',
+        r'readmanhua\.net/manga/.',
+        r'neatmanga\.com/manga/.',
+        r'manga18\.fun/manga/.',
+        r'nightcomic\.com/manga/.',
+        r'comickiba\.com/manga/.',
+        r'manganine\.com/manga/.',
+        r'primemanga\.com/manga/.',
+        r'manhuaus\.com/manga/.',
+        r'mangaread\.co/manga/.',
+        r'onmanga\.com/manga/.',
+        r'painfulnightzscan\.com/manga/.',
+        r'manga68\.com/manga/.',
+        r'sleepytranslations\.com/manga/.',
+        r'manhwahentai\.me/manga/.',
+        r'jjutsuscans\.com/manga/.',
+        r'mysticalmerries\.com/manga/.',
+        r'mangarave\.com/manga/.',
+        r'thetopcomic\.com/manga/.',
     ],
     'jaiminisbox_com': [
         r'jaiminisbox\.com/reader/series/.',
@@ -605,7 +732,6 @@ providers_list = {
         r'secretscan\.co/comics/.',
         r'lynxscans\.com/comics/.',
         r'kkjscans\.co/comics/.',
-        r'kkjscans\.co/comics/.',
         r'edelgardescans\.com/comics/.',
         r'hunlight-scans\.info/comics/.',
         r'hatigarmscanz\.net/comics/.',
