@@ -15,11 +15,13 @@ class ComicoJp(Provider, Std):
     def get_content(self):
         title_no = self.re.search(r'\.\w{2,7}/.+titleNo=(\d+)', self.get_url())
         if title_no:
-            content = self.http_post('{}/api/getArticleList.nhn'.format(self.domain), data={
-                'titleNo': title_no.group(1)
-            })
             try:
-                return self.json.loads(content).get('result', {}).get('list', [])
+                with self.http_post('{}/api/getArticleList.nhn'.format(self.domain), data={
+                    'titleNo': title_no.group(1)
+                }) as req:
+                    images = req.json().get('result', {}).get('list', [])
+
+                return images
             except TypeError:
                 pass
         return []
