@@ -8,7 +8,7 @@ class MangaFoxCom(Provider, Std):
         re = self.re.compile(r'/chapter-(\d+(?:-\d+)?)')
         return re.search(self.chapter).group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
