@@ -20,7 +20,7 @@ class MangaCanBlogCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return str(self.chapter_id)
 
-    def get_main_content(self):
+    def get_content(self):
         return self.http_get(self._home_link)
 
     @staticmethod
